%define major     %(echo %{version}|cut -d. -f1,2)
%define iconname  sylpheed.png

%define libapi    0
%define libmajor  1
%define libname   %mklibname %name %libapi %libmajor
%define develname %mklibname %name -d

Summary:	A GTK+2 based, lightweight, and fast e-mail client
Name:		sylpheed
Version:	3.7.0
%define subrel	1
Release:	%mkrel 4
Group:		Networking/Mail
License:	GPLv2
URL:		http://sylpheed.sraoss.jp/
Source0:	http://sylpheed.sraoss.jp/sylpheed/v%{major}/sylpheed-%{version}.tar.bz2
# https://bugs.mageia.org/show_bug.cgi?id=29356
# CVE-2021-37746
Patch1:		sylpheed-3.7.0-uri-check.patch
BuildRequires:	gettext-devel
BuildRequires:	gtk+2-devel >= 2.8.0
BuildRequires:	gpgme-devel > 1.0.0
BuildRequires:	pkgconfig(openssl)
BuildRequires:	imagemagick
BuildRequires:	libpilot-link-devel
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(gtkspell-2.0)

Requires:	curl
Provides:	sylpheed-main = %version-%release
Provides:	sylpheed2
Obsoletes:	sylpheed2

%description
This program is an X based fast e-mail client which has features
(or go for it :-)) like:
	o user-friendly and intuitive interface
	o integrated NetNews client (partially implemented)
	o ability of keyboard-only operation
	o Mew/Wanderlust-like key bind
	o multipart MIME
	o built-in image view
	o external editor support
	o unlimited multiple account handling
	o message queueing
	o filtering
	o XML-based address book
See 'README' for more information.

%package -n %libname
Summary:	Library files for %name
Group:		Networking/Mail

%description -n %libname
This package contains shared library files for %name.

%package -n %develname
Summary:	Development files for %name
Group:		Networking/Mail
Requires:	%libname = %version
Provides:	%name-devel = %version-%release

%description -n %develname
This package contains development files for %name.

%prep
%setup -q -n %{name}-%{version}

#switch to enchant2
sed -i -e '/PKG_CONFIG/s,enchant,enchant-2,g' configure.ac
sed -i -e 's,<enchant/enchant.h>,<enchant-2/enchant.h>,g' src/compose.c

%build
autoreconf -vfi -Iac
%configure  --enable-gpgme \
		--enable-jpilot \
		--enable-ssl \
		--enable-ldap \
		--enable-ipv6
%make_build

%install
%make_install

mkdir -p %{buildroot}{%{_miconsdir},%{_iconsdir},%{_liconsdir}}
convert sylpheed.png -geometry 48x48 %{buildroot}%{_liconsdir}/%{iconname}
convert sylpheed.png -geometry 32x32 %{buildroot}%{_iconsdir}/%{iconname}
convert sylpheed.png -geometry 16x16 %{buildroot}%{_miconsdir}/%{iconname}

# we don't want these
find %{buildroot} -name '*.la' -delete

%{find_lang} %name

%files -f %{name}.lang
%doc AUTHORS ChangeLog* NEWS README* TODO*
%{_bindir}/*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/faq
%lang(de) %doc %{_datadir}/%{name}/faq/de
%lang(en) %doc %{_datadir}/%{name}/faq/en
%lang(es) %doc %{_datadir}/%{name}/faq/es
%lang(fr) %doc %{_datadir}/%{name}/faq/fr
%lang(it) %doc %{_datadir}/%{name}/faq/it
%dir %{_datadir}/%{name}/manual
%lang(en) %doc %{_datadir}/%{name}/manual/en
%lang(ja) %doc %{_datadir}/%{name}/manual/ja
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%{_iconsdir}/%{iconname}
%{_liconsdir}/%{iconname}
%{_miconsdir}/%{iconname}

%files -n %libname
%{_libdir}/*-%{libapi}.so.%{libmajor}
%{_libdir}/*-%{libapi}.so.%{libmajor}.*

%files -n %develname
%{_libdir}/*.so
%{_includedir}/%{name}


%changelog
* Wed Aug 11 2021 wally <wally> 3.7.0-4.1.mga8
+ Revision: 1741085
- add fedora patch to fix CVE-2021-37746 (mga#29356)

* Sat Feb 15 2020 umeabot <umeabot> 3.7.0-4.mga8
+ Revision: 1523194
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Feb 23 2019 wally <wally> 3.7.0-3.mga7
+ Revision: 1369584
- switch to enchant2

* Sun Sep 23 2018 umeabot <umeabot> 3.7.0-2.mga7
+ Revision: 1301270
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 daviddavid <daviddavid> 3.7.0-1.mga7
+ Revision: 1221340
- new version: 3.7.0

* Fri Oct 13 2017 mrambo3501 <mrambo3501> 3.6.0-1.mga7
+ Revision: 1171652
- version 3.6.0

* Tue Sep 05 2017 cjw <cjw> 3.5.0-3.mga7
+ Revision: 1151582
- rebuild for openssl 1.1

* Thu Mar 03 2016 umeabot <umeabot> 3.5.0-2.mga6
+ Revision: 984152
- Rebuild for openssl

* Thu Jan 28 2016 fwang <fwang> 3.5.0-1.mga6
+ Revision: 928330
- 3.5.0

* Wed Oct 15 2014 umeabot <umeabot> 3.4.2-3.mga5
+ Revision: 750140
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.4.2-2.mga5
+ Revision: 689649
- Mageia 5 Mass Rebuild

* Wed Jun 11 2014 fwang <fwang> 3.4.2-1.mga5
+ Revision: 635577
- 3.4.2

* Sat Apr 05 2014 fwang <fwang> 3.4.1-1.mga5
+ Revision: 611972
- 3.4.1

* Mon Mar 10 2014 fwang <fwang> 3.3.1-1.mga5
+ Revision: 601637
- 3.3.1

* Fri Oct 18 2013 umeabot <umeabot> 3.3.0-4.mga4
+ Revision: 519429
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.3.0-3.mga3
+ Revision: 383873
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 13 2012 fwang <fwang> 3.3.0-2.mga3
+ Revision: 317290
- br gtkspell

* Sat Nov 10 2012 fwang <fwang> 3.3.0-1.mga3
+ Revision: 316832
- new version 3.3.0

* Fri Jun 29 2012 fwang <fwang> 3.2.0-1.mga3
+ Revision: 264917
- new version 3.2.0

* Wed Jun 06 2012 fwang <fwang> 3.1.4-1.mga3
+ Revision: 256135
- new version 3.1.4

* Thu Mar 01 2012 fwang <fwang> 3.1.3-1.mga2
+ Revision: 216377
- fix build with latest glib
- new version 3.1.3

* Thu Sep 08 2011 fwang <fwang> 3.1.2-1.mga2
+ Revision: 141361
- new version 3.1.2

* Sun Jun 19 2011 kharec <kharec> 3.1.1-1.mga2
+ Revision: 109688
- new version 3.1.1

* Tue Feb 01 2011 dmorgan <dmorgan> 3.1.0-1.mga1
+ Revision: 46057
- Remove mdv macros
- imported package sylpheed

